@@ -2,9 +2,14 @@ import json
 import logging
 from functools import wraps
 
-from django.shortcuts import render as django_render
+import django.core.exceptions
 from django.http import HttpResponseRedirect, HttpResponse
 
+try:
+    from django.shortcuts import render as django_render
+except django.core.exceptions.ImproperlyConfigured:
+    pass
+
 from utils import JSONResponse
 
 import forms
