@@ -4,8 +4,13 @@ import random
 import re
 
 from django.core.mail import EmailMultiAlternatives
-from django.db import models
 from django.template.loader import render_to_string
+import django.core.exceptions
+
+try:
+    from django.db import models
+except django.core.exceptions.ImproperlyConfigured:
+    pass
 
 from redis import Redis
 import settings
