@@ -1,5 +1,12 @@
+import django.core.exceptions
+
 from django.conf import settings
 
+try:
+    getattr(settings, '')
+except django.core.exceptions.ImproperlyConfigured:
+    settings = {}
+
 REDIS = {
     'password': '',
     'port': 6379,
