@@ -6,6 +6,7 @@ import string
 import time
 import unicodedata
 
+import django.core.exceptions
 from django.http import HttpResponse
 from django.utils.functional import lazy
 from django.core.urlresolvers import reverse
@@ -16,7 +17,10 @@ except ImportError:
     # Django 1.6+
     from django.conf.urls import url
 
-from django.views.generic.base import TemplateView
+try:
+    from django.views.generic.base import TemplateView
+except django.core.exceptions.ImproperlyConfigured:
+    pass
 
 class JSONResponse(HttpResponse):
     def __init__(self, content, content_type='application/json', *args, **kwargs):
@@ -36,37 +40,44 @@ def timestamped_file_url(prefix):
                 prefix, now, timestamp, filename)
     return inner
 
-def slugify(phrase):
+def slugify(phrase, simple=True):
     """
     Removes all non-important words to generate a meaningful slug.
     """
-    from nltk import pos_tag, word_tokenize
-    tokens = pos_tag(word_tokenize(phrase))
-    words = []
-    for token, pos in tokens:
-        if pos in [
-                'CD',
-                'IN',
-                'JJ',
-                'JJR',
-                'NN',
-                'NNP',
-                'VB',
-                'VBG',
-                'VBN',
-                'WRB']:
-            words.append(token)
-    phrase = " ".join(words)
-    symbols = re.compile(r'[^\w]')
-    dashes = re.compile(r'-+')
-    phrase = phrase.decode("unicode_escape")
-    phrase = unicodedata.normalize("NFKD", phrase)
-    phrase = phrase.encode("ascii", "ignore")
-    phrase = phrase.lower()
-    phrase = symbols.sub('-', phrase)
-    phrase = dashes.sub('-', phrase)
-    phrase = phrase.strip('-')
-    return phrase
+    if simple:
+        alphanumeric = re.compile(r'[^a-zA-Z0-9]+')
+        slug = alphanumeric.sub('-', phrase.lower()).strip('-')
+        if len(slug) == 0:
+            return random.choice(string.lowercase)
+        return slug
+    else:
+        from nltk import pos_tag, word_tokenize
+        tokens = pos_tag(word_tokenize(phrase))
+        words = []
+        for token, pos in tokens:
+            if pos in [
+                    'CD',
+                    'IN',
+                    'JJ',
+                    'JJR',
+                    'NN',
+                    'NNP',
+                    'VB',
+                    'VBG',
+                    'VBN',
+                    'WRB']:
+                words.append(token)
+        phrase = " ".join(words)
+        symbols = re.compile(r'[^\w]')
+        dashes = re.compile(r'-+')
+        phrase = phrase.decode("unicode_escape")
+        phrase = unicodedata.normalize("NFKD", phrase)
+        phrase = phrase.encode("ascii", "ignore")
+        phrase = phrase.lower()
+        phrase = symbols.sub('-', phrase)
+        phrase = dashes.sub('-', phrase)
+        phrase = phrase.strip('-')
+        return phrase
 
 def simple_url(path, view=None):
     """
